---
output:
    html_document:
#    rmdformats::html_clean:
        self_contained: false 
        keep_md: true
#        fig_caption: yes
#        toc_depth: 3
#        code_folding: "hide"
        thumbnails: false
title: "Colonization of C. elegans with the CeMBio community on PFM & NGM over Time"
author: "PD140"
date: "Last update: June 09, 2020"
#css: "/home/pdirksen/Templates/html_clean-printer.css"
---








## Introduction

This experiment aimed at characterizing the colonization of *C. elegans* N2 by the CeMBio V1.0 community over time while growing on two different media. We created the experimental microbiome by mixing OD5-adjusted monocultures of the 12 bacterial CeMBio strains in equal volumes and spotted this mixture on to either NGM or PFM agar plates. Synchronized L1 larvae were added to these plates, raised at 20 °C and harvested at L4 (48 h post L1), early adult (72 h post L1), or later adult stage (96 h post L1). For the harvest, we collected the worms from the plates, surface bleached them to remove adherent bacteria and isolated their DNA. Additionally, we measured the CFU-load of half of the worm samples by grinding 10 surface-bleached worms and plating serial dilutions of their contained bacteria. We also harvested and DNA-isolated the remaining bacterial lawns of each plate.

All DNA samples were subjected to MiSeq amplicon sequencing of the bacterial V3-V4 region.

## Methods

### Worm maintenance

Stock cultures of *C. elegans* N2 have been maintained on NGM agar plates seeded with a lawn of *Escherichia coli OP50* as previously described (Stiernagle 2006).

### Bacterial culture

All bacteria were grown aerobically in liquid LB medium or on LB-agar plates [10 g/l tryptone, 5 g/l yeast extract, 5 g/l NaCl, 15 g/l agar] at 28 °C or 25 °C, respectivly.
Active bacterial cultures were only maintained for single experiments, otherwise bacteria were stored frozen in 15% glycerol/LB at -80 °C to minimize laboratory adaptation.
Active cultures were created prior to each experiment as follows:
Material from a glycerol stock was streaked out on LB-agar plates and growing single colonies
were re-streaked and identity verified by sequencing of the 16S rRNA genes using general bacterial primers 27F (AGAGTTTGATCMTGGCTCAG) and 1492R (GGTTACCTTGTTACGACTT). Single colonies from verified cultures were then used to inoculate the main bacterial cultures in liquid LB as described above.

### Microbiome establishment experiment var. AG Schulenburg

All bacteria were grown either in 50 ml falcon tubes or 250 ml Erlenmeyer flasks with 1/5 of the flask volume filled with LB medium over night at 28 C as described above. Cultures were harvested by centrifugation, washed three times with PBS, and adjusted to a final optical density at 600 nm of 5 in PBS. The cultures were then mixed in equal volumes to create the CeMBio community inoculum.

Synchronized *C. elegans* L1 larvae were raised at 20 °C on 6 cm plates containing either NGM or PFM agar seeded with 250 μl of the CeMBio inoculum. Nematodes and bacterial lawns were harvested after 48 h, 72 h, and 96 h with M9-T (M9 + 0.025% Triton X-100).

Surface-adherent bacteria were removed using a modification of our previously described procedure allowing for an efficient removal of bacteria attached to the worm's surface while retaining nematodes alive (Dirksen et al. 2016, Andre's paper):
In general, suspended worms were placed in the top of pipette tips containing a 10 µm filter and repeatedly incubated with washing solutions. 
After incubation, the solution was then cleared by centrifugation of the tip box.
The order of solutions was:
two times 3 min of M9-T + 25 mM tetramizole hydrochloride to anesthetize the worms for a short period and prevent subsequent bleach intake;
once 4 min of M9-T + 2% bleach (equal volumes of 12% sodium hypochlorite and 5 N NaOH, 
Stiernagle 2006);
twice 3 min of M9-T to clear the bleach.
Washed worms were then pelleted by centrifugtation and either frozen at -20 °C for microbiome
analysis or subjected to immediate CFU extraction.

### CFU extraction

Ten surface sterilized nematodes were transferred to a 2 ml reagent tube containing 100 µl M9-T and 10--20 1 mm zirkonium beads.
Nematode counts were verified by microscopy and any deviations noted for analysis.
Samples were then homogenized using a Geno/Grinder 2000 (SPEX SamplePrep, Metuchen, USA) at 
1500 strokes / min for 3 min.
The homogenate was serially diluted in M9-T and three times 5 µl of all dilutions were plated on LB-agar.
After 48 h of incubation at 25 °C, the plates were imaged and appropriate dilutions counted
manually from the images.

### Microbiome analysis

Frozen surface sterilized worm samples were resuspended in buffer T1 from the NucleoSpin® Tissue Kit (Macherey & Nagel) and processed with the additional steps described in the "Support protocol for bacteria" as per the manufacturer's instructions. Barcoded amplicon sequencing of the V3-V4 region of the bacterial 16S rRNA gene was carried out by the Institute for Clinical Molecular Biology, Kiel, Germany, using Illumina MiSeq 2x300 bp technology.

Adapter and primer sequences were removed using cutadapt (http://dx.doi.org/10.14806/ej.17.1.200) Amplicon sequence variants (ASVs) were then resolved using dada2 (https://doi.org/10.1038/nmeth.3869) with default parameters except for the following settings: sequence truncation length forward/reverse: 250/200 (longest expected amplicon: 428 nt); 
taxonomic assignment with silva trainset release 132;
species assignment with a custom reference set of genome-derived 16 S sequence variants of
the CeMBio strains;

The denoised ASV frequency data was analysed in R using the following packages:
DECIPHER, phyloseq, DESeq2, vegan, ggplot2.

All scripts to reproduce this analysis can be obtained from the author's git repository:
*git clone https://bitbucket.org/phdirksen/pd140_cembio_colonization.git*


## Analysis preparation

### Data and metadata

Overview over all experimental variables:

**Experimental variables**:  
*medium*: The experimental medium, NGM or PFM (Note: The inoculum was suspended in PBS and is 
noted as accordingly, although this is nonsensical in an experimental point of view)  
*time*: The time of plate harvest / developmental age of the worms  
*type* / *bacteria*: The type of sample, being either derived from worms, corresponding plate 
lawns, negative controls (empty experimental plates, DNA-extraction controls, and sequencing 
controls), or the positive controls (mock communities)  

**Other variables** (Not used in analysis)  
*ID*: The random ID assigned to a single replicate of a treatment and used to identify the sample
over the course of the experiment  
*lms*: Sample identifier of the sequencing center  
*DNA_batch*: DNA extraction was done in 2 batches, split according to random ID  



      medium     time        bacteria         ID         type      DNA_batch        lms    
---  --------  --------  -------------  ------------  ---------  ------------  ------------
     NGM :66   0 h : 4   cembio  :124   102    :  2   ctrl : 8   Min.   :1.0   I18461 :  1 
     PBS : 4   48 h:44   dna_ctrl:  4   103    :  2   lawns:70   1st Qu.:1.0   I18462 :  1 
     PFM :66   72 h:44   mock    :  2   104    :  2   mock : 2   Median :1.5   I18463 :  1 
     NA's:10   96 h:44   none    : 12   105    :  2   worms:66   Mean   :1.5   I18464 :  1 
               NA's:10   seq_ctrl:  4   106    :  2              3rd Qu.:2.0   I18465 :  1 
                                        107    :  2              Max.   :2.0   I18466 :  1 
                                        (Other):134              NA's   :2     (Other):140 



### Technical assessment and quality control

#### Positive controls / mock community

The experiment contained two positive control samples with DNA from the ZymoBIOMICS™ Microbial
Community Standard (Zymo Research).
After denoising with the dada2 pipeline, the eight bacterial species of the standard were captured
in 10 ASVs, all identical in sequence to the reference sequences provided by the manufacturer.
Thus, the sequencing and denoising processes seemingly resulted in highly accurate amplicon 
sequence variants.



<img src="Kiel_figures/Figure_S1_mock_community.png" width="960" style="display: block; margin: auto;" />
**Figure S1: Comparison of the mock community with the theoretical proportions.**
The two mock samples sequenced in this study **(A)** show now obvious difference to the expected
theoretical proportions of the reference **(B, bar with label *theoretical*)**.


#### Negative controls

This assay included three types of negative controls: 
(a) CFU / washing controls: plates without bacteria or worms
(b) DNA extraction controls: empty DNA extractions to check for cross contaminations, and
(c) Sequencing controls: water samples handed in for sequencing to control for external
contaminations



<img src="Kiel_figures/Figure_S2_negative_controls.png" width="960" style="display: block; margin: auto;" />
**Figure S2: Negative controls** The assay contained three types of negative controls:
DNA extraction controls, sequencing controls, and experimental controls.
All DNA and sequencing controls, as well as most experimental controls produced only an
negligible amount of reads if any, and can thus be deemed clean. 
Only two experimental negative controls are the exception: 
L18571 produced only reads assignable to MYb11, which was never used alone, thus
indicating a low-level contamination amplified via PCR.
The most abundant organism in the second control, L18548, is likewise MYb11.
As none of the experimental samples contain such an amount of this bacterium and
it was never used solo, a low-level contamination amplified via PCR is again
the most likely explanation.
In conclusion, the assay can be considered generally not affected by foreign
contaminations, and is unlikely to have been affected by cross-contaminations in
a significant manner.

#### Check for obvious contaminants

Amplifying bacterial DNA from worms had been generally hard before and contaminations were easily
amplified if DNA concentration was low, leading to the exclusion of samples from previous assays
(Dirksen et al 2016).
Therefore the taxonomic composition was examined for obvious contaminants at class level.
All samples displayed the expected composition of Gamma-, Alphaproteobacteria, and Bacteroidia, 
The only exception was worm sample 27, which included Bacilli that were not part of the CeMBio
strains, but part of the mock community and thus are a likely cross-contamination.
Sample 27 (worm I18477 / lawn I18550) has therefore been excluded from further analysis.



<img src="Kiel_figures/Figure_S3_class_overview.png" width="1344" style="display: block; margin: auto;" />
**Figure S3: Taxonomic composition of all samples on class level.**
Taxonomic composition is Gamma-, Alphaproteobacteria, and Bacteroidia, which is
what we would expect based on the CeMBio strains.
Few samples contain the remaining detected classes, which are most likely reagent
contaminations.
Sample 27 contains also Bacilli reads, which were not among the experimental
strains, but among the mock community.





### Identifying unresolved ASVs representing the CeMBio community

The total number of ASVs in the whole dataset is 401. 
However, only 16 ASVs are needed to account for 99.9% of all reads:

<img src="Kiel_figures/Figure_S4_req_ASVs.png" width="672" style="display: block; margin: auto;" />
**Figure S4: Cumulative proportion of reads**. In total 16 ASVs account for 99.87% of all reads.


#### Merging ASVs belonging to the same CeMBio strain

Out of these 16 ASVs, 12 were identical in sequence to CeMBio 16S sequences, while 4 could not
be resolved to strain level, likely due to sequencing artifacts despite denoising with dada2.



No   Family                Genus              Species                             
---  --------------------  -----------------  ------------------------------------
1    Rhizobiaceae          Brucella           MYb71_1/MYb71_2                     
2    Sphingobacteriaceae   Sphingobacterium   BIGb0170_1/BIGb0170_2               
3    Xanthomonadaceae      Stenotrophomonas   JUb19                               
4    Weeksellaceae         Chryseobacterium   JUb44                               
5    Moraxellaceae         Acinetobacter      MYb10_1                             
6    Enterobacteriaceae                       BIGb0393_1/BIGb0393_6/BIGb0393_7    
7    Pseudomonadaceae      Pseudomonas                                            
8    Pseudomonadaceae      Pseudomonas        MSPm1_1                             
9    Burkholderiaceae                         BIGb0172                            
10   Enterobacteriaceae    Lelliottia         JUb66_1/JUb66_2                     
11   Pseudomonadaceae      Pseudomonas        MYb11_1                             
12   Enterobacteriaceae                       CEent1_1/CEent1_2/CEent1_3/CEent1_5 
13   Enterobacteriaceae                                                           
14   Enterobacteriaceae    Lelliottia                                             
15   Enterobacteriaceae    Enterobacter       CEent1_4                            
16   Sphingomonadaceae     Sphingomonas       JUb134                              

In order to resolve these ambigous ASVs, BLAST analysis was performed against the genome-derived
16S sequences of the CeMBio strains.
As a result, the ambigous ASV were assigned the following identities:


query acc.ver                                                       subject acc.ver    % identity   bit score   evalue
------------------------------------------------------------------  ----------------  -----------  ----------  -------
ASV001-Rhizobiaceae-Brucella-MYb71_1/MYb71_2                        MYb71                 100.000         743        0
ASV002-Sphingobacteriaceae-Sphingobacterium-BIGb0170_1/BIGb0170_2   BIGb0170              100.000         780        0
ASV003-Xanthomonadaceae-Stenotrophomonas-JUb19                      JUb19                 100.000         789        0
ASV004-Weeksellaceae-Chryseobacterium-JUb44                         JUb44                 100.000         780        0
ASV005-Moraxellaceae-Acinetobacter-MYb10_1                          MYb10                 100.000         791        0
ASV006-Enterobacteriaceae-NA-BIGb0393_1/BIGb0393_6/BIGb0393_7       BIGb0393              100.000         789        0
ASV007-Pseudomonadaceae-Pseudomonas-NA                              MSPm1                  99.766         784        0
ASV008-Pseudomonadaceae-Pseudomonas-MSPm1_1                         MSPm1                 100.000         789        0
ASV009-Burkholderiaceae-NA-BIGb0172                                 BIGb0172              100.000         789        0
ASV010-Enterobacteriaceae-Lelliottia-JUb66_1/JUb66_2                JUb66                 100.000         789        0
ASV011-Pseudomonadaceae-Pseudomonas-MYb11_1                         MYb11                 100.000         789        0
ASV012-Enterobacteriaceae-NA-CEent1_1/CEent1_2/CEent1_3/CEent1_5    CeEnt1                100.000         789        0
ASV013-Enterobacteriaceae-NA-NA                                     BIGb0393               99.766         784        0
ASV014-Enterobacteriaceae-Lelliottia-NA                             JUb66                  99.766         784        0
ASV015-Enterobacteriaceae-Enterobacter-CEent1_4                     CeEnt1                100.000         789        0
ASV018-Sphingomonadaceae-Sphingomonas-JUb134                        JUb134                100.000         743        0

Finally, the ASV belonging to the same organism were merged, leading to the following final ASVs:


No   Family                Genus              Species    ASV    
---  --------------------  -----------------  ---------  -------
1    Rhizobiaceae          Ochrobactrum       MYb71      ASV001 
2    Sphingobacteriaceae   Sphingobacterium   BIGb0170   ASV002 
3    Xanthomonadaceae      Stenotrophomonas   JUb19      ASV003 
4    Weeksellaceae         Chryseobacterium   JUb44      ASV004 
5    Moraxellaceae         Acinetobacter      MYb10      ASV005 
6    Enterobacteriaceae    Pantoea            BIGb0393   Merged 
7    Pseudomonadaceae      Pseudomonas        MSPm1      Merged 
8    Burkholderiaceae      Comamonas          BIGb0172   ASV009 
9    Enterobacteriaceae    Lelliottia         JUb66      Merged 
10   Pseudomonadaceae      Pseudomonas        MYb11      ASV011 
11   Enterobacteriaceae    Enterobacter       CEent1     Merged 
12   Sphingomonadaceae     Sphingomonas       JUb134     ASV018 

#### Adjusting counts by rRNA copy number

We have all the genomes and information on rRNA gene number per strain.
This data can be used to adjust the raw reads counts by gene copy number to enhance the estimate
of relative cell counts.


 BIGb0170   BIGb0172   BIGb0393   CEent1   JUb19   JUb44
---------  ---------  ---------  -------  ------  ------
        7          6          7        8       4       7



 JUb66   JUb134   MYb10   MYb11   MYb71   MSPm1
------  -------  ------  ------  ------  ------
     7        3       7       5       4       4


## Results and Discussion

Cembio strains are an ecologically informed synthetic microbiome for lab experiments  
First question: how do they colonize in lab experiments and does that resemle ecology?  
*The* default method: Culturing *C. elegans* on NGM plates seeded with a bacterial lawn until they reach the desired stage (Stiernagle 2006).  
As an alternative, one can use PFM, which limits bacterial proliferation on plate and thus allowsfor improved control of experimental conditions (Dirksen 2016)  
Therefore, we tested colonization on both media for L4 worms (48 h post L1), young adults and later adults (72 h and 96 h post L1).


### All CeMBio strains colonize the worms

The CeMBio strains were able to persist as a community both on plates and in nematodes.
All 12 strains could be detected in the lawns of both NGM and PFM plates at all measured time points (figure 1D).
In *C. elegans* nematodes, all strains could be reliably detected with the exception of JUb134, which was present mostly in trace amounts, if at all:
only in 2/10 replicates of the 96 h time point of NGM-raised worms, or in 2/9, 5/10, and 2/10 of the 48 h, 72 h, and 96 h time points of PFM-raised worms, respectively (figure 1D).
In the microbiomes of NGM-raised nematodes, three strains were highly prevalent: *Ochrobactrum* MYb71 (41% mean relative abundance), *Stenotrophomonas* JUb19 (37%), and BIGb0170 (14%, figure 1B).
The communities of PFM-raised nematodes were less even, consisting mostly of MYb71 (75%).
For the 48 h and 72 h time points, JUb19 (11%) was second most prevalent, but got replaced by *Pantoea* BIGb0393 at the 96 h time point.
These results suggest, that some microbes such as MYb71 and JUb19 form a relatively stable core community, while the abundance of otheres depends more on environmntal or age-related constraints (JUb19 in late PFM-nematodes, *Sphingobacterium* BIGb0170, *Pseudomonas* MYb11, *Pantoea* BIGb0393).


Discussion points

- Replacement of JUb19 by BIGb0393 at 96 h despite being highly prevalent in the lawns
- JUb134 only older worms on PFM => stress (starving conditions when PFM lawn depleted?)
  - Similarly, Sphingomonas only in few worms naturally, but then high abundance
- All strains are maintained on the lawns (Fig 1D, 12 observed species throughout)



**Table S1: Taxonomic composition of worms raised on NGM and PFM agar plates.** 

<table class="kable_wrapper">
<tbody>
  <tr>
   <td> 

Medium   Species     Mean prop.   Cum. prop.
-------  ---------  -----------  -----------
NGM      MYb71        0.4126074    0.4126074
NGM      JUb19        0.3688494    0.7814568
NGM      BIGb0170     0.1353079    0.9167647
NGM      BIGb0172     0.0243797    0.9411445
NGM      JUb66        0.0145049    0.9556494
NGM      JUb44        0.0140910    0.9697403
NGM      CEent1       0.0117067    0.9814470
NGM      MYb10        0.0116136    0.9930606
NGM      BIGb0393     0.0024415    0.9955022
NGM      MYb11        0.0023725    0.9978747
NGM      MSPm1        0.0021253    1.0000000
NGM      JUb134       0.0000000    1.0000000

 </td>
   <td> 

Medium   Species     Mean prop.   Cum. prop.
-------  ---------  -----------  -----------
PFM      MYb71        0.7496773    0.7496773
PFM      JUb19        0.1063122    0.8559895
PFM      MYb11        0.0265090    0.8824985
PFM      BIGb0393     0.0254988    0.9079973
PFM      MSPm1        0.0173698    0.9253672
PFM      JUb44        0.0171685    0.9425356
PFM      BIGb0172     0.0167190    0.9592546
PFM      JUb66        0.0148604    0.9741150
PFM      BIGb0170     0.0104404    0.9845554
PFM      CEent1       0.0096834    0.9942388
PFM      MYb10        0.0056250    0.9998638
PFM      JUb134       0.0001362    1.0000000

 </td>
  </tr>
</tbody>
</table>



```
## 
## 	Pairwise comparisons using t tests with pooled SD 
## 
## data:  estimate_richness(ps_exp)$InvSimpson and paste(sample_data(ps_exp)$med_type, sample_data(ps_exp)$time) 
## 
##                NGM lawns 48 h NGM lawns 72 h NGM lawns 96 h NGM worms 48 h
## NGM lawns 72 h 0.10252        -              -              -             
## NGM lawns 96 h 0.01615        0.45773        -              -             
## NGM worms 48 h 0.00021        0.03808        0.19537        -             
## NGM worms 72 h 0.00092        0.10025        0.38171        0.68283       
## NGM worms 96 h 0.00261        0.18187        0.55244        0.48111       
## PBS lawns 0 h  < 2e-16        < 2e-16        < 2e-16        < 2e-16       
## PFM lawns 48 h 2.2e-16        < 2e-16        < 2e-16        < 2e-16       
## PFM lawns 72 h 2.7e-11        3.9e-15        < 2e-16        < 2e-16       
## PFM lawns 96 h 0.01149        0.39204        0.89685        0.24205       
## PFM worms 48 h 3.4e-11        1.0e-07        3.0e-06        0.00053       
## PFM worms 72 h 5.1e-14        3.0e-10        1.4e-08        6.0e-06       
## PFM worms 96 h < 2e-16        4.8e-14        2.9e-12        2.5e-09       
##                NGM worms 72 h NGM worms 96 h PBS lawns 0 h PFM lawns 48 h
## NGM lawns 72 h -              -              -             -             
## NGM lawns 96 h -              -              -             -             
## NGM worms 48 h -              -              -             -             
## NGM worms 72 h -              -              -             -             
## NGM worms 96 h 0.75630        -              -             -             
## PBS lawns 0 h  < 2e-16        < 2e-16        -             -             
## PFM lawns 48 h < 2e-16        < 2e-16        3.4e-11       -             
## PFM lawns 72 h < 2e-16        < 2e-16        1.0e-15       0.01805       
## PFM lawns 96 h 0.44671        0.63615        < 2e-16       < 2e-16       
## PFM worms 48 h 0.00012        3.6e-05        < 2e-16       < 2e-16       
## PFM worms 72 h 1.0e-06        2.5e-07        < 2e-16       < 2e-16       
## PFM worms 96 h 3.1e-10        6.5e-11        < 2e-16       < 2e-16       
##                PFM lawns 72 h PFM lawns 96 h PFM worms 48 h PFM worms 72 h
## NGM lawns 72 h -              -              -              -             
## NGM lawns 96 h -              -              -              -             
## NGM worms 48 h -              -              -              -             
## NGM worms 72 h -              -              -              -             
## NGM worms 96 h -              -              -              -             
## PBS lawns 0 h  -              -              -              -             
## PFM lawns 48 h -              -              -              -             
## PFM lawns 72 h -              -              -              -             
## PFM lawns 96 h < 2e-16        -              -              -             
## PFM worms 48 h < 2e-16        5.1e-06        -              -             
## PFM worms 72 h < 2e-16        2.5e-08        0.33529        -             
## PFM worms 96 h < 2e-16        5.5e-12        0.00895        0.10025       
## 
## P value adjustment method: fdr
```

<img src="Kiel_figures/Figure_1_tax_overview.png" width="1440" style="display: block; margin: auto;" />
**Figure 1: Taxonomic composition of colonized *C. elegans* nematodes and plate lawns.**
**(A)** Proportion of CeMBio reads in the initial community assembly used as inoculum for the lawns.
**(B)** Proportion of CeMBio reads in NGM worm and lawn samples.
**(C)** Proportion of CeMBio reads in PFM worm and lawn samples.
**(D)** Alpha diversity measures of mean observed no. of species (top) and Inverse Simpson Index (bottom) with standard deviation indicating richness and diversity of the communities. 


### Correlation of bacterial composition and load


A major drawback of amplicon sequencing data is the inability to infere absolut bacterial frequencies from it.
In order to assess absolute bacterial frequencies, we analysed bacterial colony forming units (CFUs) for 5 of the 10 replicate worm populations per medium and time point.
In general, the number of CFUs increased from 48 h to 96 h tenfold, and NGM-raised worms harboured 7 - 10 times more CFUs than PFM-raised worms (figure 2A).
In addition, if bacterial diversity of nematodes is analysed by principle coordinate analysis of Bray-Curtis distances, CFU count significantly explains the result of this ordination (generalized additive model, df = 15, F = 2.523, p < 10^-5, R-square = 0.57 - Remarks: Plot looks nice and suggests a connection between CFUs and taxonomy, although I guess it's just cofounded by the CFU-difference of PFM-NGM, which is the mapped on axis 1).


Discussion points

- higher CFU on NGM thatn PFM due to higher bacterial proliferation in nutrient richer conditions?
- CFU counts should be representative of actual conditions as all cembio strains are cultureable, and observed colony phenotypes are consistent with MYb71 (many small slow growing colonies)
- Observed CFU counts ranged over two orders of magnitude and are generally consistent with previous findings (Nancy, Lopez et al biorxiv).
- CFUs raising over time also consistent with literature








<img src="Kiel_figures/Figure_CFUload.png" width="960" style="display: block; margin: auto;" />
**Figure 2: Bacterial load of *C. elegans* nematodes colonized by the CeMBio community**
**(A)** Colony forming units in single nematodes.
**(B)** Principle coordinate analysis of Bray Curtis distances.
CFU-load, overlayed as a smooth response surface, is a significant predictor of the ordination
result (Generalized additive model, df = 15, F = 2.523, p < 10^-5, R-square = 0.57)



```
## 
## Family: gaussian 
## Link function: identity 
## 
## Formula:
## y ~ te(x1, x2, k = c(4, 4), bs = c("tp", "tp"), fx = c(FALSE, 
##     FALSE))
## 
## Parametric coefficients:
##             Estimate Std. Error t value Pr(>|t|)    
## (Intercept)  3.28652    0.08457   38.86   <2e-16 ***
## ---
## Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
## 
## Approximate significance of smooth terms:
##             edf Ref.df     F  p-value    
## te(x1,x2) 2.631     15 2.523 5.37e-06 ***
## ---
## Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
## 
## R-sq.(adj) =  0.574   Deviance explained = 61.4%
## -ML = 21.522  Scale est. = 0.20741   n = 29
```

### Differential abundance of bacteria between worms and lawns

Next, we adressed the question in how far nematodes differ from their respective environments, the plate lawns.
We compared the differences of the nematode communities to their respective plate lawns using DESeq2's differential abundance analysis (figure 3A).
The most enriched bacteria in nematodes (given as mean +/- standard error of the fold-change), regardless of medium or time, 
were the dominating strain MYb71 (13 +/- 1.3), 
and the two Enterobacteriaceae, *Enterobacter* CEent1 and *Lelliottia* JUb66 (2.0 +/- 1.2, and 1.9 +/- 1.2, respectively).
Other strains were enriched in a context-dependend manner.
For example, BIGb0393 was either not enriched or even decreased under all conditions, except in late PFM-raised worms, where it is strongly enriched (8.0 +/- 1.5) compared to it's abundance in the lawns.
JUb19, although being the second most abdundant strain in worms, is either constantly enriched in NGM-worms (1.5 - 1.6 times) or strongly enriched early (3.6 +/- 1.2 at 48 h), but then depleted over time (2.4 +/- 1.2 and 0.25 +/- 1.4 at 72 h and 96 h, respectively).
Other strains, such as JUb44 and JUb134 are generally depleted in worms compared to lawns.
Taken together, these results again indicate that the CeMBio community contains a combination of strong general colonizers (MYb71, JUb19 except in 96 h PFM nematodes) and situational colonizers (BIGb0393, JUb19), thus having the potential to show specific responses to a variety of environmental conditions.
Analysis of the community composition via principle coordinate analysis of Bray-Curtis distances also reveals the clear distinction between nematode and lawn samples (figure 3B).
Interestingly, the bacterial mixture used to inoculate the plates is highly similar to the plate lawns of the 48 h and 72 h time points.
This highlights that the use of peptone free medium enhances the experimenter's control over the initial und medium-term stability of the microbial environment on the assay plates compared to the use of traditional NGM.





### Beta diversity




<img src="Kiel_figures/Figure_bdiv.png" width="960" style="display: block; margin: auto;" />
**Figure: Effect of medium and developmental time on microbiome diversity.**
**(A)** Differential abundance of the CeMBio strains in *C. elegans* nematodes compared
to the plate lawns.
Positive fold change indicates increased abundance in worms compared to lawns.
Data was normalized and analysed using DESeq2. Filled points indicate fold
changes significantly different from 0 for with a p < 0.01. 
**(B)** PCoA with Bray-Curtis distance.
Ellipses denote lawn and worm samples, respectively.


<img src="Kiel_figures/Figure_network.png" width="960" />

# Figures for the manuscript

<img src="Kiel_figures/Figure_2.png" width="1152" style="display: block; margin: auto;" />
Figure 2


<img src="Kiel_figures/sfigure_qc.png" width="960" style="display: block; margin: auto;" />
Supplementary figure: Microbiome analysis controls


<img src="Kiel_figures/sfigure_deseq2.png" width="672" style="display: block; margin: auto;" />
Supplementary figure: DESeq2 analysis

# Session information


```
## R version 3.5.3 (2019-03-11)
## Platform: x86_64-apple-darwin15.6.0 (64-bit)
## Running under: macOS Mojave 10.14.6
## 
## Matrix products: default
## BLAS: /Library/Frameworks/R.framework/Versions/3.5/Resources/lib/libRblas.0.dylib
## LAPACK: /Library/Frameworks/R.framework/Versions/3.5/Resources/lib/libRlapack.dylib
## 
## locale:
## [1] en_US.UTF-8/en_US.UTF-8/en_US.UTF-8/C/en_US.UTF-8/en_US.UTF-8
## 
## attached base packages:
##  [1] grid      stats4    parallel  stats     graphics  grDevices utils    
##  [8] datasets  methods   base     
## 
## other attached packages:
##  [1] vegan_2.5-6                 lattice_0.20-41            
##  [3] permute_0.9-5               forcats_0.5.0              
##  [5] stringr_1.4.0               dplyr_0.8.5                
##  [7] purrr_0.3.3                 readr_1.3.1                
##  [9] tidyr_1.0.2                 tibble_3.0.0               
## [11] tidyverse_1.3.0             qgraph_1.6.5               
## [13] RColorBrewer_1.1-2          png_0.1-7                  
## [15] phyloseq_1.26.1             ggthemes_4.2.0             
## [17] ggpubr_0.2.5                magrittr_1.5               
## [19] ggplot2_3.3.0               ggnewscale_0.4.1           
## [21] gridExtra_2.3               DESeq2_1.22.2              
## [23] SummarizedExperiment_1.12.0 DelayedArray_0.8.0         
## [25] BiocParallel_1.16.6         matrixStats_0.56.0         
## [27] Biobase_2.42.0              GenomicRanges_1.34.0       
## [29] GenomeInfoDb_1.18.2         DECIPHER_2.10.2            
## [31] RSQLite_2.2.0               Biostrings_2.50.2          
## [33] XVector_0.22.0              IRanges_2.16.0             
## [35] S4Vectors_0.20.1            BiocGenerics_0.28.0        
## 
## loaded via a namespace (and not attached):
##   [1] readxl_1.3.1           backports_1.1.6        Hmisc_4.4-0           
##   [4] BDgraph_2.62           plyr_1.8.6             igraph_1.2.5          
##   [7] splines_3.5.3          digest_0.6.25          foreach_1.5.0         
##  [10] htmltools_0.4.0        fansi_0.4.1            checkmate_2.0.0       
##  [13] memoise_1.1.0          cluster_2.1.0          annotate_1.60.1       
##  [16] modelr_0.1.6           jpeg_0.1-8.1           colorspace_1.4-1      
##  [19] rvest_0.3.5            blob_1.2.1             haven_2.2.0           
##  [22] xfun_0.13              crayon_1.3.4           RCurl_1.98-1.1        
##  [25] jsonlite_1.6.1         genefilter_1.64.0      survival_3.1-12       
##  [28] iterators_1.0.12       ape_5.3                glue_1.4.0            
##  [31] gtable_0.3.0           zlibbioc_1.28.0        Rhdf5lib_1.4.3        
##  [34] abind_1.4-5            scales_1.1.0           DBI_1.1.0             
##  [37] Rcpp_1.0.4.6           isoband_0.2.1          viridisLite_0.3.0     
##  [40] xtable_1.8-4           htmlTable_1.13.3       foreign_0.8-76        
##  [43] bit_1.1-15.2           Formula_1.2-3          httr_1.4.1            
##  [46] htmlwidgets_1.5.1      lavaan_0.6-5           acepack_1.4.1         
##  [49] ellipsis_0.3.0         farver_2.0.3           pkgconfig_2.0.3       
##  [52] XML_3.99-0.3           nnet_7.3-13            dbplyr_1.4.2          
##  [55] locfit_1.5-9.4         labeling_0.3           tidyselect_1.0.0      
##  [58] rlang_0.4.5            reshape2_1.4.4         AnnotationDbi_1.44.0  
##  [61] cellranger_1.1.0       munsell_0.5.0          tools_3.5.3           
##  [64] cli_2.0.2              generics_0.0.2         ade4_1.7-15           
##  [67] broom_0.5.5            fdrtool_1.2.15         evaluate_0.14         
##  [70] biomformat_1.10.1      yaml_2.2.1             fs_1.4.1              
##  [73] knitr_1.28             bit64_0.9-7            glasso_1.11           
##  [76] pbapply_1.4-2          nlme_3.1-147           whisker_0.4           
##  [79] xml2_1.3.1             compiler_3.5.3         rstudioapi_0.11       
##  [82] ggsignif_0.6.0         reprex_0.3.0           huge_1.3.4.1          
##  [85] geneplotter_1.60.0     pbivnorm_0.6.0         stringi_1.4.6         
##  [88] highr_0.8              Matrix_1.2-18          psych_1.9.12.31       
##  [91] multtest_2.38.0        vctrs_0.2.4            pillar_1.4.3          
##  [94] lifecycle_0.2.0        cowplot_1.0.0          data.table_1.12.8     
##  [97] bitops_1.0-6           corpcor_1.6.9          R6_2.4.1              
## [100] latticeExtra_0.6-28    codetools_0.2-16       MASS_7.3-51.5         
## [103] gtools_3.8.2           assertthat_0.2.1       rhdf5_2.26.2          
## [106] rjson_0.2.20           withr_2.1.2            mnormt_1.5-6          
## [109] GenomeInfoDbData_1.2.0 hms_0.5.3              mgcv_1.8-31           
## [112] rpart_4.1-15           rmarkdown_2.1          d3Network_0.5.2.1     
## [115] lubridate_1.7.8        base64enc_0.1-3
```

